==> nifi-1.20.0-source-release.zip: nifi-1.20.0/nifi-toolkit/nifi-toolkit-cli/src/main/java/org/apache/nifi/toolkit/cli/impl/result/nifi/ReportingTaskResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.toolkit.cli.impl.result.nifi;

import org.apache.commons.lang3.Validate;
import org.apache.nifi.toolkit.cli.api.ResultType;
import org.apache.nifi.toolkit.cli.impl.result.AbstractWritableResult;
import org.apache.nifi.web.api.dto.BundleDTO;
import org.apache.nifi.web.api.dto.ReportingTaskDTO;
import org.apache.nifi.web.api.entity.ReportingTaskEntity;

import java.io.IOException;
import java.io.PrintStream;

public class ReportingTaskResult extends AbstractWritableResult<ReportingTaskEntity> {

    private final ReportingTaskEntity reportingTaskEntity;

    public ReportingTaskResult(final ResultType resultType, final ReportingTaskEntity reportingTaskEntity) {
        super(resultType);
        this.reportingTaskEntity = reportingTaskEntity;
        Validate.notNull(reportingTaskEntity);
    }

    @Override
    public ReportingTaskEntity getResult() {
        return reportingTaskEntity;
    }

    @Override
    protected void writeSimpleResult(final PrintStream output) throws IOException {
        final ReportingTaskDTO reportingTaskDTO = reportingTaskEntity.getComponent();

        final BundleDTO bundle = reportingTaskDTO.getBundle();
        output.printf("Name  : %s\nID    : %s\nType  : %s\nBundle: %s - %s %s\nState : %s\n",
                reportingTaskDTO.getName(), reportingTaskDTO.getId(), reportingTaskDTO.getType(),
                bundle.getGroup(), bundle.getArtifact(), bundle.getVersion(), reportingTaskDTO.getState());
    }
}

==> nifi-1.28.1-source-release.zip: nifi-1.28.1/nifi-toolkit/nifi-toolkit-cli/src/main/java/org/apache/nifi/toolkit/cli/impl/result/nifi/ReportingTaskResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.toolkit.cli.impl.result.nifi;

import org.apache.nifi.toolkit.cli.api.ResultType;
import org.apache.nifi.toolkit.cli.impl.result.AbstractWritableResult;
import org.apache.nifi.web.api.dto.BundleDTO;
import org.apache.nifi.web.api.dto.ReportingTaskDTO;
import org.apache.nifi.web.api.entity.ReportingTaskEntity;

import java.io.IOException;
import java.io.PrintStream;
import java.util.Objects;

public class ReportingTaskResult extends AbstractWritableResult<ReportingTaskEntity> {

    private final ReportingTaskEntity reportingTaskEntity;

    public ReportingTaskResult(final ResultType resultType, final ReportingTaskEntity reportingTaskEntity) {
        super(resultType);
        this.reportingTaskEntity = Objects.requireNonNull(reportingTaskEntity);
    }

    @Override
    public ReportingTaskEntity getResult() {
        return reportingTaskEntity;
    }

    @Override
    protected void writeSimpleResult(final PrintStream output) throws IOException {
        final ReportingTaskDTO reportingTaskDTO = reportingTaskEntity.getComponent();

        final BundleDTO bundle = reportingTaskDTO.getBundle();
        output.printf("Name  : %s\nID    : %s\nType  : %s\nBundle: %s - %s %s\nState : %s\n",
                reportingTaskDTO.getName(), reportingTaskDTO.getId(), reportingTaskDTO.getType(),
                bundle.getGroup(), bundle.getArtifact(), bundle.getVersion(), reportingTaskDTO.getState());
    }
}
